@@ -1,12 +1,12 @@
 #' An Enhanced Version of as.numeric
 #'
-#' This function coerces an object into a numeric vector. There are several differences between 
+#' This function coerces objects into a numeric vector. There are several differences between 
 #' this function and \code{as.numeric}. First, if \code{as.character2} fails to coerce (this is 
 #' usually because there are characters in the input object), it will raise an error and stop 
 #' rather than to give a warning. Second, it can handle data frame object, list, and recursive 
 #' list. Third, it can coerce number-like factors exactly into what users see on the screen.
 #'
-#' @param x an object to be coerced.
+#' @param ... one or more objects to be coerced.
 #'
 #' @return a numeric vector, or, if fails, an error will be raised.
 #'
@@ -16,7 +16,7 @@
 #' a <- c(55, 66, 77, 88, 66, 77, 88)
 #' b <- factor(a)
 #' df <- data.frame(a, b)
-#' as.numeric2(df)
+#' as.numeric2(df, a*2)
 #' # Try a list
 #' l <- list(a, a*2)
 #' as.numeric2(l)
@@ -24,14 +24,14 @@
 #' l2 <- list(l, l)
 #' as.numeric2(l2)
 as.numeric2 <-
-function(x) {
-  y <- as.character2(x)
+function(...) {
+  y <- as.character2(...)
   len_of_na1 <- length(which(is.na(y)))
   yy <- as.numeric(y)
   rm(y)
   len_of_na2 <- length(which(is.na(yy)))
   if (len_of_na2 > len_of_na1) {
-    stop("Some elements of x cannot be coerced to numeric.")
+    stop("Some elements cannot be coerced to numeric.")
   }
   else {
     return(yy)
