@@ -121,6 +121,9 @@
 #' @param special a length 1 character or regular expression to be passed to \code{dir_or_file} 
 #' to specify what pattern should be met by filenames. The default is to read all files.
 #' See \code{\link{dir_or_file}}.
+#' @param use_stri_replace_all default is FALSE. If it is TRUE, 
+#' \code{stringi::stri_replace_all} is used to delete stop words, which has 
+#' a slightly higher speed. This is still experimental.
 #'
 #' @return a corpus, or document term matrix, or term document matrix. 
 #'
@@ -139,6 +142,142 @@
 #' dtm <- corp_or_dtm(x, from = "v", type="d", control = list(wordLengths = c(3, 20)))
 #' tdm <- corp_or_dtm(x, from = "v", type = "T", stop_word = c("you", "to", "a", "of"))
 corp_or_dtm <-
+function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cutter, stop_word = NULL, stop_pattern = NULL, control = "auto",
+  myfun1 = NULL, myfun2 = NULL, special = "", use_stri_replace_all=FALSE) {
+  INFOLOCALE <- localestart2()
+  on.exit(localeend2(INFOLOCALE))
+  message("CHECKING ARGUMENTS")
+  if (!is.null(stop_word)) {
+    stop_word <- as.character2(stop_word)
+    stop_word <- stop_word[!is.na(stop_word)]
+    if (length(stop_word) == 0) 
+      stop_word <- NULL
+  }
+  if (!is.null(myfun1)){
+    stopifnot(is.function(myfun1))
+	FUN1 <- match.fun(myfun1)
+  }
+  if (!is.null(myfun2)){
+    stopifnot(is.function(myfun2))
+	FUN2 <- match.fun(myfun2)
+  }
+  if (!is.null(stop_pattern)) 
+    stopifnot(all(!is.na(stop_pattern)))
+  if (is.null(type)) 
+    stop("Argument type should not be NULL.")
+  type <- as.character(type[1])
+  if (grepl("^d|^D|^t|^T", type)){
+    control <- chEck_cOntrOl(control)
+  }
+  input <- c(...)
+  if (!is_character_vector(input))
+    stop("Your input should be characters.")
+  input[is.na(input)] <- ""
+  if (from == "dir") {
+    message("PROCESSING FILE NAMES")
+    fullname <- dir_or_file_self(input, special = special)
+    seged_vec <- rep(NA, length(fullname))
+    message("READING AND PROCESSING FILES")
+    for (i in 1:length(fullname)) {
+      fi <- fullname[i]
+      the_enc <- gEtthEEnc(x1 = fi, x2 = enc)
+      conved <- scancn(fi, enc = the_enc)
+      if (!is.null(myfun1) && grepl("[^[:space:]]", conved) == TRUE) {
+        conved <- AftEr_myfUn(FUN1(conved))
+      }	  
+      if (!is.null(mycutter)) {
+        conved <- gsub("\\s+", " ", paste0(jiebaR::segment(conved, jiebar = mycutter), collapse = " "))
+      }
+      if (!is.null(myfun2) && grepl("[^[:space:]]", conved) == TRUE) {
+        conved <- AftEr_myfUn(FUN2(conved), pa = TRUE)
+      }
+      seged_vec[i] <- conved
+    }
+	rm(input)
+    message("CREATING CORPUS")
+    corp <- tm::Corpus(tm::VectorSource(seged_vec))
+    rm(seged_vec)
+  }
+  if (from == "v") {
+    input <- gsub("\\\\(t|r|n|)", " ", input)
+	input <- gsub("\\s+$", "", input)
+    if (any(file.exists(input))) {
+      stop("Some strings are identical to filenames in working directory, please make some changes.")
+    }
+    message("PROCESSING CHARACTER VECTOR")
+	length_of_v_input <- length(input)
+    seged_vec <- rep(NA, length_of_v_input)
+    for (i in 1:length(input)) {
+      ii <- input[i]
+      if (ii %in% c(NA, "NA", "?") | grepl("[^[:space:]]", ii) == FALSE) {
+        message("Element ", i, " may be blank or missing, set it to a space.")
+        ii <- " "
+      }
+      if (is.function(myfun1) && grepl("[^[:space:]]", ii) == TRUE) {
+        ii <- AftEr_myfUn(FUN1(ii))
+	  }
+      if (!is.null(mycutter)) {
+        ii <- gsub("\\s+", " ", paste(jiebaR::segment(ii, mycutter), collapse = " "))
+      }
+      if (is.function(myfun2) && grepl("[^[:space:]]", ii) == TRUE) {
+        ii <- AftEr_myfUn(FUN2(ii), pa = TRUE)
+      }
+      seged_vec[i] <- ii
+    }
+	rm(input)
+    message("GENERATING CORPUS")
+    corp <- tm::Corpus(tm::VectorSource(seged_vec))
+    rm(seged_vec)
+  }
+  message("PROCESSING CORPUS")
+  corp <- suppressWarnings(tm::tm_map(corp, tm::removePunctuation))
+  corp <- suppressWarnings(tm::tm_map(corp, tm::removeNumbers))
+  corp <- suppressWarnings(tm::tm_map(corp, tm::content_transformer(tolower)))
+  
+  # check whether to use stri_replace_all
+  REMOVEFUN <- if (use_stri_replace_all==FALSE) tm::removeWords else STRI_REPLACE
+   
+  if (!is.null(stop_word)) {
+    if (stop_word[1] %in% c("jiebar", "auto", "jiebaR")) {
+      corp <- suppressWarnings(tm::tm_map(corp, REMOVEFUN, c(find_jiebar_stop())))
+    }
+    else {
+      corp <- suppressWarnings(tm::tm_map(corp, REMOVEFUN, c(stop_word)))
+    }
+  }
+  if (!is.null(stop_pattern)) {
+    stop_pattern <- as.character2(stop_pattern)
+    stop_pattern <- paste(stop_pattern, collapse = "|")
+    corp <- suppressWarnings(tm::tm_map(corp, tm::removeWords, c(stop_pattern)))
+  }
+  corp <- suppressWarnings(tm::tm_map(corp, tm::stripWhitespace))
+  if (grepl("^c|^C", type)) {
+    message("DONE")
+    return(corp)
+  }
+  else if (grepl("^d|^D|^t|^T", type)) {
+    message("MAKING DTM/TDM")
+    todtm=ifelse (grepl("^d|^D", type), TRUE, FALSE)
+    DTMname <- rE_dtm(corp, todtm = todtm, re_control = control)
+	rm(corp)
+	if (from == "dir"){
+		DTMname$dimnames$Docs <- fullname
+		rm(fullname)
+	}
+	if (from == "v"){
+		DTMname$dimnames$Docs <- as.character(1: length_of_v_input)
+	}	
+    message("DONE")
+	return(DTMname)
+  }
+  else {
+    message("You do not specify a valid type, so return corpus.")
+	message("DONE")
+    return(corp)
+  }
+}
+
+corp_or_dtm_new <-
 function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cutter, stop_word = NULL, stop_pattern = NULL, control = "auto",
   myfun1 = NULL, myfun2 = NULL, special = "") {
   INFOLOCALE <- localestart2()
@@ -180,16 +319,13 @@ function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cu
       the_enc <- gEtthEEnc(x1 = fi, x2 = enc)
       conved <- scancn(fi, enc = the_enc)
       if (!is.null(myfun1) && grepl("[^[:space:]]", conved) == TRUE) {
-        conved <- FUN1(conved)
-		conved <- AftEr_myfUn(conved)
+        conved <- AftEr_myfUn(FUN1(conved))
       }	  
       if (!is.null(mycutter)) {
-        conved <- paste0(jiebaR::segment(conved, jiebar = mycutter), collapse = " ")
-        conved <- gsub("\\s+", " ", conved)
+        conved <- gsub("\\s+", " ", paste0(jiebaR::segment(conved, jiebar = mycutter), collapse = " "))
       }
       if (!is.null(myfun2) && grepl("[^[:space:]]", conved) == TRUE) {
-        conved <- FUN2(conved)
-		conved <- AftEr_myfUn(conved, pa = TRUE)
+        conved <- AftEr_myfUn(FUN2(conved), pa = TRUE)
       }
       seged_vec[i] <- conved
     }
@@ -214,16 +350,13 @@ function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cu
         ii <- " "
       }
       if (is.function(myfun1) && grepl("[^[:space:]]", ii) == TRUE) {
-        ii <- FUN1(ii)
-        ii <- AftEr_myfUn(ii)
+        ii <- AftEr_myfUn(FUN1(ii))
 	  }
       if (!is.null(mycutter)) {
-        ii <- paste(jiebaR::segment(ii, mycutter), collapse = " ")
-        ii <- gsub("\\s+", " ", ii)
+        ii <- gsub("\\s+", " ", paste(jiebaR::segment(ii, mycutter), collapse = " "))
       }
       if (is.function(myfun2) && grepl("[^[:space:]]", ii) == TRUE) {
-        ii <- FUN2(ii)
-        ii <- AftEr_myfUn(ii, pa = TRUE)
+        ii <- AftEr_myfUn(FUN2(ii), pa = TRUE)
       }
       seged_vec[i] <- ii
     }
@@ -233,23 +366,23 @@ function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cu
     rm(seged_vec)
   }
   message("PROCESSING CORPUS")
-  corp <- tm::tm_map(corp, tm::removePunctuation)
-  corp <- tm::tm_map(corp, tm::removeNumbers)
-  corp <- tm::tm_map(corp, tm::content_transformer(tolower))
-  if (!is.null(stop_word)) {
+  corp <- suppressWarnings(tm::tm_map(corp, tm::removePunctuation))
+  corp <- suppressWarnings(tm::tm_map(corp, tm::removeNumbers))
+  corp <- suppressWarnings(tm::tm_map(corp, tm::content_transformer(tolower)))
+  if (!is.null(stop_word) & ! grepl("^d|^D|^t|^T", type)) {
     if (stop_word[1] %in% c("jiebar", "auto", "jiebaR")) {
-      corp <- tm::tm_map(corp, tm::removeWords, c(find_jiebar_stop()))
+      corp <- suppressWarnings(tm::tm_map(corp, tm::removeWords, c(find_jiebar_stop())))
     }
     else {
-      corp <- tm::tm_map(corp, tm::removeWords, c(stop_word))
+      corp <- suppressWarnings(tm::tm_map(corp, tm::removeWords, c(stop_word)))
     }
   }
   if (!is.null(stop_pattern)) {
     stop_pattern <- as.character2(stop_pattern)
     stop_pattern <- paste(stop_pattern, collapse = "|")
-    corp <- tm::tm_map(corp, tm::removeWords, c(stop_pattern))
+    corp <- suppressWarnings(tm::tm_map(corp, tm::removeWords, c(stop_pattern)))
   }
-  corp <- tm::tm_map(corp, tm::stripWhitespace)
+  corp <- suppressWarnings(tm::tm_map(corp, tm::stripWhitespace))
   if (grepl("^c|^C", type)) {
     message("DONE")
     return(corp)
@@ -257,7 +390,7 @@ function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cu
   else if (grepl("^d|^D|^t|^T", type)) {
     message("MAKING DTM/TDM")
     todtm=ifelse (grepl("^d|^D", type), TRUE, FALSE)
-    DTMname <- rE_dtm(corp, todtm = todtm, re_control = control)
+    DTMname <- rE_dtm_new(corp, todtm = todtm, re_control = control, MYSTOP=stop_word)
 	rm(corp)
 	if (from == "dir"){
 		DTMname$dimnames$Docs <- fullname
@@ -275,3 +408,12 @@ function(..., from = "dir", type = "corpus", enc = "auto", mycutter = DEFAULT_cu
     return(corp)
   }
 }
+
+STRI_REPLACE=function(X, MYSTOP){
+	stringi::stri_replace_all(
+		X, 
+		replacement="", 
+		regex=paste("\\b", MYSTOP, "\\b", sep=""), 
+		vectorize_all=FALSE
+	)
+}
